@@ -341,8 +341,6 @@ std::ostream& operator<< (std::ostream& os, const Material& shader) {
 
 typedef std::function<void(const std::string&)> ShaderNameCallback;
 
-class ModuleObserver;
-
 const char* const MODULE_SHADERSYSTEM = "MaterialManager";
 
 /**
@@ -372,6 +370,15 @@ public:
 	 */
 	virtual bool isRealised() = 0;
 
+	// Signal which is invoked when the materials defs have been parsed
+	// Note that the DEF files might be parsed in a separate thread so 
+	// any call acquiring material info might need to block and wait for 
+	// that background call to finish before it can yield results.
+	virtual sigc::signal<void>& signal_DefsLoaded() = 0;
+
+	// Signal invoked when the material defs have been unloaded due 
+	// to a filesystem or other configuration change
+	virtual sigc::signal<void>& signal_DefsUnloaded() = 0;
 
 	/** Activate the shader for a given name and return it. The default shader
 	 * will be returned if name is not found.
@@ -405,9 +412,6 @@ public:
      */
     virtual void setActiveShaderUpdates(bool val) = 0;
 
-  virtual void attach(ModuleObserver& observer) = 0;
-  virtual void detach(ModuleObserver& observer) = 0;
-
   virtual void setLightingEnabled(bool enabled) = 0;
 
   virtual const char* getTexturePrefix() const = 0;
