@@ -1,8 +1,8 @@
 #pragma once
 
 #include <string>
+#include <sigc++/connection.h>
 #include "debugging/debugging.h"
-#include "moduleobservers.h"
 #include "util/Noncopyable.h"
 #include "irender.h"
 #include "shaderlib.h"
@@ -14,20 +14,9 @@
  * shadersystem reference available.
  */
 class SurfaceShader :
-    public ModuleObserver,
-    public util::Noncopyable
+    public util::Noncopyable,
+	public Shader::Observer
 {
-public:
-    // Observer classes can be attached to SurfaceShader to get notified
-    // on realisation/unrealisation
-    class Observer
-    {
-    public:
-        virtual ~Observer() {}
-        virtual void realiseShader() = 0;
-        virtual void unrealiseShader() = 0;
-    };
-
 private:
     // greebo: The name of the material
     std::string _materialName;
@@ -41,8 +30,9 @@ private:
 
     bool _realised;
 
-    typedef std::set<Observer*> Observers;
-    Observers _observers;
+	// Client signals
+	sigc::signal<void> _signalRealised;
+	sigc::signal<void> _signalUnrealised;
 
 public:
     // Constructor. The renderSystem reference will be kept internally as reference
@@ -145,87 +135,87 @@ public:
         captureShader();
     }
 
-    void attachObserver(Observer& observer)
-    {
-        // Insert the observer into our observer set
-        std::pair<Observers::iterator, bool> result = _observers.insert(&observer);
+	// Get the signal which is fired when this shader is realised
+	sigc::signal<void>& signal_Realised()
+	{
+		return _signalRealised;
+	}
 
-        ASSERT_MESSAGE(result.second, "SurfaceShader::attachObserver(): Observer already attached.");
+	// Get the signal which is fired when this shader is unrealised
+	sigc::signal<void>& signal_Unrealised()
+	{
+		return _signalUnrealised;
+	}
 
-        if (_realised)
-        {
-            observer.realiseShader();
-        }
-    }
-
-    void detachObserver(Observer& observer)
-    {
-        if (_realised)
-        {
-            observer.unrealiseShader();
-        }
-
-        ASSERT_MESSAGE(_observers.find(&observer) != _observers.end(), "SurfaceShader::detachObserver(): Cannot detach non-existing observer.");
-
-        // Remove after unrealising
-        _observers.erase(&observer);
-    }
-
-    // ModuleObserver methods
-    void realise() override
+	// Called when the GL shader is realised
+    void realise()
     {
         assert(!_realised);
         _realised = true;
 
-        for (auto i : _observers) i->realiseShader();
+		signal_Realised().emit();
     }
 
-    void unrealise() override
+	// Called when the GL shader is unrealised
+    void unrealise()
     {
         assert(_realised);
 
-        for (auto i : _observers) i->unrealiseShader();
+		signal_Unrealised().emit();
 
         _realised = false;
     }
 
+	bool isRealised() const
+	{
+		return _realised;
+	}
+
 private:
     // Shader capture and release
     void captureShader()
     {
+		// Release previous resources in any case
+		releaseShader();
+
         // Check if we have a rendersystem - can we capture already?
         if (_renderSystem)
         {
-            releaseShader();
-
             _glShader = _renderSystem->capture(_materialName);
             assert(_glShader);
 
-            _glShader->attach(*this);
+			_glShader->attachObserver(*this);
 
             if (_inUse)
             {
                 _glShader->incrementUsed();
             }
         }
-        else
-        {
-            releaseShader();
-        }
     }
 
     void releaseShader()
     {
         if (_glShader)
         {
+			_glShader->detachObserver(*this);
+
             if (_inUse)
             {
                 _glShader->decrementUsed();
             }
 
-            _glShader->detach(*this);
-
             _glShader.reset();
         }
     }
+
+	// Inherited via Observer
+	void onShaderRealised() override
+	{
+		realise();
+	}
+
+	void onShaderUnrealised() override
+	{
+		unrealise();
+	}
 };
