@@ -19,26 +19,20 @@
 namespace ui
 {
 
-namespace
-{
-	const char* const DIFF_ICON = "sr_icon_custom.png";
-}
-
-DifficultyEditor::DifficultyEditor(wxWindow* parent, const std::string& label,
-								   const difficulty::DifficultySettingsPtr& settings) :
-	_settings(settings),
-	_label(label),
-	_settingsView(nullptr),
-	_classCombo(nullptr),
-	_spawnArgEntry(nullptr),
-	_argumentEntry(nullptr),
-	_appTypeCombo(nullptr),
-	_saveSettingButton(nullptr),
-	_deleteSettingButton(nullptr),
-	_createSettingButton(nullptr),
-	_refreshButton(nullptr),
-	_noteText(nullptr),
-	_updateActive(false)
+DifficultyEditor::DifficultyEditor(wxWindow* parent,
+                                   const difficulty::DifficultySettingsPtr& settings)
+: _settings(settings),
+  _settingsView(nullptr),
+  _classCombo(nullptr),
+  _spawnArgEntry(nullptr),
+  _argumentEntry(nullptr),
+  _appTypeCombo(nullptr),
+  _saveSettingButton(nullptr),
+  _deleteSettingButton(nullptr),
+  _createSettingButton(nullptr),
+  _refreshButton(nullptr),
+  _noteText(nullptr),
+  _updateActive(false)
 {
 	// The actual editor pane
 	_editor = loadNamedPanel(parent, "DifficultyEditorMainPanel");
@@ -49,21 +43,11 @@ DifficultyEditor::DifficultyEditor(wxWindow* parent, const std::string& label,
 	updateEditorWidgets();
 }
 
-wxWindow* DifficultyEditor::getEditor()
+wxWindow* DifficultyEditor::getWidget()
 {
 	return _editor;
 }
 
-std::string DifficultyEditor::getNotebookLabel()
-{
-	return _label;
-}
-
-std::string DifficultyEditor::getNotebookIconName()
-{
-	return DIFF_ICON;
-}
-
 void DifficultyEditor::populateWindow()
 {
 	wxPanel* viewPanel = findNamedObject<wxPanel>(_editor, "DifficultyEditorTreeViewPanel");
