@@ -50,6 +50,9 @@ private:
 	void onMapEvent(IMap::MapEvent ev);
 	void onRadiantStartup();
 	void onIntervalReached(wxTimerEvent& ev);
+	void readFromMapProperties();
+	void writeToMapProperties(const scene::IMapRootNodePtr& root);
+	void onResourceExporting(const scene::IMapRootNodePtr& root);
 };
 
 }
