@@ -16,8 +16,10 @@
 #include "iradiant.h"
 #include "imainframe.h"
 #include "imapresource.h"
+#include "imapinfofile.h"
 #include "iaasfile.h"
 #include "igame.h"
+#include "imapformat.h"
 
 #include "registry/registry.h"
 #include "stream/TextFileInputStream.h"
@@ -37,11 +39,12 @@
 #include "map/StartupMapLoader.h"
 #include "map/RootNode.h"
 #include "map/MapResource.h"
-#include "map/algorithm/Merge.h"
+#include "map/algorithm/Import.h"
 #include "map/algorithm/Export.h"
 #include "map/algorithm/Traverse.h"
 #include "map/algorithm/MapExporter.h"
 #include "model/ModelExporter.h"
+#include "model/ModelScalePreserver.h"
 #include "map/algorithm/Skins.h"
 #include "ui/mru/MRU.h"
 #include "ui/mainframe/ScreenUpdateBlocker.h"
@@ -52,6 +55,7 @@
 #include "modulesystem/ModuleRegistry.h"
 #include "modulesystem/StaticModule.h"
 #include "RenderableAasFile.h"
+#include "MapPropertyInfoFileModule.h"
 
 #include <fmt/format.h>
 #include "algorithm/ChildPrimitives.h"
@@ -59,15 +63,10 @@
 namespace map 
 {
 
-    namespace 
-	{
-        const char* const MAP_UNNAMED_STRING = N_("unnamed.map");
-
-        const char* const GKEY_LAST_CAM_POSITION = "/mapFormat/lastCameraPositionKey";
-        const char* const GKEY_LAST_CAM_ANGLE = "/mapFormat/lastCameraAngleKey";
-        const char* const GKEY_PLAYER_START_ECLASS = "/mapFormat/playerStartPoint";
-        const char* const GKEY_PLAYER_HEIGHT = "/defaults/playerHeight";
-    }
+namespace 
+{
+    const char* const MAP_UNNAMED_STRING = N_("unnamed.map");
+}
 
 Map::Map() :
     _lastCopyMapName(""),
@@ -79,7 +78,7 @@ Map::Map() :
 void Map::loadMapResourceFromPath(const std::string& path)
 {
 	// Map loading started
-	signal_mapEvent().emit(MapLoading);
+	emitMapEvent(MapLoading);
 
 	_resource = GlobalMapResourceManager().loadFromPath(_mapName);
 
@@ -115,7 +114,7 @@ void Map::loadMapResourceFromPath(const std::string& path)
     }
 
     // Map loading finished, emit the signal
-    signal_mapEvent().emit(MapLoaded);
+    emitMapEvent(MapLoaded);
 }
 
 void Map::updateTitle()
@@ -190,22 +189,9 @@ scene::IMapRootNodePtr Map::getRoot()
     return scene::IMapRootNodePtr();
 }
 
-MapFormatPtr Map::getFormatForFile(const std::string& filename)
-{
-    // Look up the module name which loads the given extension
-    std::string gameType = GlobalGameManager().currentGame()->getKeyValue("type");
-
-    MapFormatPtr mapFormat = GlobalMapFormatManager().getMapFormatForGameType(
-        gameType, os::getExtension(filename));
-
-    ASSERT_MESSAGE(mapFormat != NULL, "map format not found for file " + filename);
-
-    return mapFormat;
-}
-
 MapFormatPtr Map::getFormat()
 {
-    return getFormatForFile(_mapName);
+    return GlobalMapFormatManager().getMapFormatForFilename(_mapName);
 }
 
 // free all map elements, reinitialize the structures that depend on them
@@ -213,13 +199,13 @@ void Map::freeMap()
 {
 	// Fire the map unloading event, 
 	// This will de-select stuff, clear the pointfile, etc.
-	signal_mapEvent().emit(MapUnloading);
+    emitMapEvent(MapUnloading);
 
 	setWorldspawn(scene::INodePtr());
 
 	GlobalSceneGraph().setRoot(scene::IMapRootNodePtr());
 
-	signal_mapEvent().emit(MapUnloaded);
+    emitMapEvent(MapUnloaded);
 
     // Reset the resource pointer
     _resource.reset();
@@ -246,103 +232,6 @@ void Map::focusViews(const Vector3& point, const Vector3& angles) {
     GlobalXYWnd().setOrigin(point);
 }
 
-void Map::removeCameraPosition() {
-    const std::string keyLastCamPos = game::current::getValue<std::string>(GKEY_LAST_CAM_POSITION);
-    const std::string keyLastCamAngle = game::current::getValue<std::string>(GKEY_LAST_CAM_ANGLE);
-
-    if (_worldSpawnNode != NULL) {
-        // Retrieve the entity from the worldspawn node
-        Entity* worldspawn = Node_getEntity(_worldSpawnNode);
-        assert(worldspawn != NULL); // This must succeed
-
-        worldspawn->setKeyValue(keyLastCamPos, "");
-        worldspawn->setKeyValue(keyLastCamAngle, "");
-    }
-}
-
-/* greebo: Saves the current camera position/angles to worldspawn
- */
-void Map::saveCameraPosition()
-{
-    const std::string keyLastCamPos = game::current::getValue<std::string>(GKEY_LAST_CAM_POSITION);
-    const std::string keyLastCamAngle = game::current::getValue<std::string>(GKEY_LAST_CAM_ANGLE);
-
-    if (_worldSpawnNode != NULL) {
-        // Retrieve the entity from the worldspawn node
-        Entity* worldspawn = Node_getEntity(_worldSpawnNode);
-        assert(worldspawn != NULL); // This must succeed
-
-        ui::CamWndPtr camWnd = GlobalCamera().getActiveCamWnd();
-        if (camWnd == NULL) return;
-
-        worldspawn->setKeyValue(keyLastCamPos,
-                                string::to_string(camWnd->getCameraOrigin()));
-        worldspawn->setKeyValue(keyLastCamAngle,
-                                string::to_string(camWnd->getCameraAngles()));
-    }
-}
-
-/** Find the start position in the map and focus the viewport on it.
- */
-void Map::gotoStartPosition()
-{
-    const std::string keyLastCamPos = game::current::getValue<std::string>(GKEY_LAST_CAM_POSITION);
-    const std::string keyLastCamAngle = game::current::getValue<std::string>(GKEY_LAST_CAM_ANGLE);
-    const std::string eClassPlayerStart = game::current::getValue<std::string>(GKEY_PLAYER_START_ECLASS);
-
-    Vector3 angles(0,0,0);
-    Vector3 origin(0,0,0);
-
-    if (_worldSpawnNode != NULL) {
-        // Retrieve the entity from the worldspawn node
-        Entity* worldspawn = Node_getEntity(_worldSpawnNode);
-        assert(worldspawn != NULL); // This must succeed
-
-        // Try to find a saved "last camera position"
-        const std::string savedOrigin = worldspawn->getKeyValue(keyLastCamPos);
-
-        if (savedOrigin != "")
-        {
-            // Construct the vector out of the std::string
-            origin = string::convert<Vector3>(savedOrigin);
-
-            angles = string::convert<Vector3>(
-                worldspawn->getKeyValue(keyLastCamAngle)
-            );
-
-            // Focus the view with the default angle
-            focusViews(origin, angles);
-
-            // Remove the saved entity key value so it doesn't appear during map edit
-            removeCameraPosition();
-
-            return;
-        }
-        else
-        {
-            // Get the player start entity
-            Entity* playerStart = Scene_FindEntityByClass(eClassPlayerStart);
-
-            if (playerStart != NULL)
-            {
-                // Get the entity origin
-                origin = string::convert<Vector3>(
-                    playerStart->getKeyValue("origin")
-                );
-
-                // angua: move the camera upwards a bit
-				origin.z() += game::current::getValue<float>(GKEY_PLAYER_HEIGHT);
-
-                // Check for an angle key, and use it if present
-                angles[ui::CAMERA_YAW] = string::convert<float>(playerStart->getKeyValue("angle"), 0);
-            }
-        }
-    }
-
-    // Focus the view with the given parameters
-    focusViews(origin, angles);
-}
-
 scene::INodePtr Map::findWorldspawn()
 {
 	scene::INodePtr worldspawn;
@@ -406,9 +295,6 @@ void Map::load(const std::string& filename) {
     rMessage() << GlobalCounters().getCounter(counterPatches).get() << " patches\n";
     rMessage() << GlobalCounters().getCounter(counterEntities).get() << " entities\n";
 
-    // Move the view to a start position
-    gotoStartPosition();
-
     // Let the filtersystem update the filtered status of all instances
     GlobalFilterSystem().update();
 
@@ -427,18 +313,7 @@ bool Map::save(const MapFormatPtr& mapFormat)
 
 	blocker.setMessage(_("Preprocessing"));
 
-	try
-	{
-		signal_mapEvent().emit(IMap::MapSaving);
-	}
-	catch (std::runtime_error& ex)
-	{
-		wxutil::Messagebox::ShowError(
-			fmt::format(_("Failure running map pre-save event:\n{0}"), ex.what()));
-	}
-
-    // Store the camview position into worldspawn
-    saveCameraPosition();
+    emitMapEvent(MapSaving);
 
     wxutil::ScopeTimer timer("map save");
 
@@ -447,10 +322,7 @@ bool Map::save(const MapFormatPtr& mapFormat)
     // Save the actual map resource
     bool success = _resource->save(mapFormat);
 
-	signal_mapEvent().emit(IMap::MapSaved);
-
-    // Remove the saved camera position
-    removeCameraPosition();
+    emitMapEvent(MapSaved);
 
     if (success)
     {
@@ -494,20 +366,10 @@ bool Map::import(const std::string& filename)
             // is not the NULL node
             scene::INodePtr otherRoot = resource->getNode();
 
-            // Adjust all new names to fit into the existing map namespace,
-            // this routine will be changing a lot of names in the importNamespace
-            INamespacePtr nspace = getRoot()->getNamespace();
+            // Adjust all new names to fit into the existing map namespace
+            algorithm::prepareNamesForImport(getRoot(), otherRoot);
 
-            if (nspace)
-            {
-                // Prepare our namespace for import
-                nspace->ensureNoConflicts(otherRoot);
-
-                // Now add the imported names to the local namespace
-                nspace->connect(otherRoot);
-            }
-
-            MergeMap(otherRoot);
+            algorithm::mergeMap(otherRoot);
             success = true;
         }
     }
@@ -530,7 +392,7 @@ bool Map::saveDirect(const std::string& filename, const MapFormatPtr& mapFormat)
 
 	if (!mapFormat)
 	{
-		format = getFormatForFile(filename);
+		format = GlobalMapFormatManager().getMapFormatForFilename(filename);
 	}
 
     bool result = MapResource::saveFile(
@@ -558,7 +420,7 @@ bool Map::saveSelected(const std::string& filename, const MapFormatPtr& mapForma
 
 	if (!format)
 	{
-		format = getFormatForFile(filename);
+		format = GlobalMapFormatManager().getMapFormatForFilename(filename);
 	}
 
     bool success = MapResource::saveFile(
@@ -757,19 +619,22 @@ void Map::registerCommands()
     GlobalCommandSystem().addCommand("SaveMap", Map::saveMap);
     GlobalCommandSystem().addCommand("SaveMapAs", Map::saveMapAs);
     GlobalCommandSystem().addCommand("SaveMapCopyAs", Map::saveMapCopyAs);
-    GlobalCommandSystem().addCommand("SaveSelected", Map::exportMap);
+    GlobalCommandSystem().addCommand("ExportMap", Map::exportMap);
+    GlobalCommandSystem().addCommand("SaveSelected", Map::exportSelection);
 	GlobalCommandSystem().addCommand("ReloadSkins", map::algorithm::reloadSkins);
 	GlobalCommandSystem().addCommand("ExportSelectedAsModel", map::algorithm::exportSelectedAsModelCmd,
-		cmd::Signature(cmd::ARGTYPE_STRING, cmd::ARGTYPE_STRING, 
-					   cmd::ARGTYPE_INT|cmd::ARGTYPE_OPTIONAL, 
-					   cmd::ARGTYPE_INT|cmd::ARGTYPE_OPTIONAL, 
-					   cmd::ARGTYPE_INT|cmd::ARGTYPE_OPTIONAL));
+        { cmd::ARGTYPE_STRING, 
+          cmd::ARGTYPE_STRING,
+          cmd::ARGTYPE_INT | cmd::ARGTYPE_OPTIONAL,
+          cmd::ARGTYPE_INT | cmd::ARGTYPE_OPTIONAL,
+          cmd::ARGTYPE_INT | cmd::ARGTYPE_OPTIONAL });
 
     GlobalEventManager().addCommand("NewMap", "NewMap");
     GlobalEventManager().addCommand("OpenMap", "OpenMap");
     GlobalEventManager().addCommand("ImportMap", "ImportMap");
     GlobalEventManager().addCommand("LoadPrefab", "LoadPrefab");
     GlobalEventManager().addCommand("SaveSelectedAsPrefab", "SaveSelectedAsPrefab");
+    GlobalEventManager().addCommand("ExportMap", "ExportMap");
     GlobalEventManager().addCommand("SaveMap", "SaveMap");
     GlobalEventManager().addCommand("SaveMapAs", "SaveMapAs");
     GlobalEventManager().addCommand("SaveMapCopyAs", "SaveMapCopyAs");
@@ -835,6 +700,23 @@ void Map::saveMap(const cmd::ArgumentList& args)
 }
 
 void Map::exportMap(const cmd::ArgumentList& args)
+{
+    auto fileInfo = MapFileManager::getMapFileSelection(false, _("Export Map"), filetype::TYPE_MAP_EXPORT);
+
+	if (!fileInfo.fullPath.empty())
+	{
+        GlobalMap().emitMapEvent(MapSaving);
+
+        MapResource::saveFile(*fileInfo.mapFormat,
+            GlobalSceneGraph().root(),
+            traverse,
+            fileInfo.fullPath);
+
+        GlobalMap().emitMapEvent(MapSaved);
+    }
+}
+
+void Map::exportSelection(const cmd::ArgumentList& args)
 {
     MapFileSelection fileInfo =
         MapFileManager::getMapFileSelection(false, _("Export selection"), filetype::TYPE_MAP);
@@ -871,79 +753,14 @@ void Map::rename(const std::string& filename) {
     }
 }
 
-void Map::importSelected(std::istream& in)
-{
-    scene::INodePtr root = std::make_shared<scene::BasicRootNode>();
-
-    // Instantiate the default import filter
-    class MapImportFilter :
-        public IMapImportFilter
-    {
-    private:
-        scene::INodePtr _root;
-    public:
-        MapImportFilter(const scene::INodePtr& root) :
-            _root(root)
-        {}
-
-        bool addEntity(const scene::INodePtr& entityNode)
-        {
-            _root->addChildNode(entityNode);
-            return true;
-        }
-
-        bool addPrimitiveToEntity(const scene::INodePtr& primitive, const scene::INodePtr& entity)
-        {
-            if (Node_getEntity(entity)->isContainer())
-            {
-                entity->addChildNode(primitive);
-                return true;
-            }
-            else
-            {
-                return false;
-            }
-        }
-    } importFilter(root);
-
-    MapFormatPtr format = getFormat();
-
-    IMapReaderPtr reader = format->getMapReader(importFilter);
-
-    try
-    {
-        // Start parsing
-        reader->readFromStream(in);
-
-        // Prepare child primitives
-        addOriginToChildPrimitives(root);
-
-        // Adjust all new names to fit into the existing map namespace,
-        // this routine will be changing a lot of names in the importNamespace
-        INamespacePtr nspace = getRoot()->getNamespace();
-        if (nspace)
-        {
-            // Prepare all names, but do not import them into the namesace. This
-            // will happen during the MergeMap call.
-            nspace->ensureNoConflicts(root);
-        }
-
-        MergeMap(root);
-    }
-    catch (IMapReader::FailureException& e)
-    {
-        wxutil::Messagebox::ShowError(
-            fmt::format(_("Failure reading map from clipboard:\n{0}"), e.what()));
-
-        // Clear out the root node, otherwise we end up with half a map
-        scene::NodeRemover remover;
-        root->traverseChildren(remover);
-    }
-}
-
 void Map::exportSelected(std::ostream& out)
 {
-    MapFormatPtr format = getFormat();
+    exportSelected(out, getFormat());
+}
+
+void Map::exportSelected(std::ostream& out, const MapFormatPtr& format)
+{
+    assert(format);
 
     IMapWriterPtr writer = format->getMapWriter();
 
@@ -954,6 +771,18 @@ void Map::exportSelected(std::ostream& out)
     exporter.exportMap(GlobalSceneGraph().root(), traverseSelected);
 }
 
+void Map::emitMapEvent(MapEvent ev)
+{
+    try
+    {
+        signal_mapEvent().emit(ev);
+    }
+    catch (std::runtime_error & ex)
+    {
+        wxutil::Messagebox::ShowError(fmt::format(_("Failure running map event {0}:\n{1}"), ev, ex.what()));
+    }
+}
+
 // RegisterableModule implementation
 const std::string& Map::getName() const
 {
@@ -970,7 +799,9 @@ const StringSet& Map::getDependencies() const
         _dependencies.insert(MODULE_RADIANT);
 		_dependencies.insert(MODULE_GAMEMANAGER);
 		_dependencies.insert(MODULE_SCENEGRAPH);
+		_dependencies.insert(MODULE_MAPINFOFILEMANAGER);
 		_dependencies.insert(MODULE_FILETYPES);
+		_dependencies.insert(MODULE_MAPRESOURCEMANAGER);
     }
 
     return _dependencies;
@@ -990,8 +821,14 @@ void Map::initialiseModule(const ApplicationContext& ctx)
     registerCommands();
 
 	_scaledModelExporter.initialise();
+    _modelScalePreserver.reset(new ModelScalePreserver);
 
 	MapFileManager::registerFileTypes();
+
+    // Register an info file module to save the map property bag
+    GlobalMapInfoFileManager().registerInfoFileModule(
+        std::make_shared<MapPropertyInfoFileModule>()
+    );
 }
 
 void Map::shutdownModule()
@@ -1000,17 +837,9 @@ void Map::shutdownModule()
 
 	GlobalSceneGraph().removeSceneObserver(this);
 
+    _modelScalePreserver.reset();
 	_startupMapLoader.reset();
 	_mapPositionManager.reset();
 }
 
-// Creates the static module instance
-module::StaticModule<Map> staticMapModule;
-
 } // namespace map
-
-// Accessor method containing the singleton Map instance
-map::Map& GlobalMap() 
-{
-    return *map::staticMapModule.getModule();
-}
