@@ -30,8 +30,13 @@ void MapFileManager::registerFileTypes()
 {
 	// Register the map file extension in the FileTypeRegistry
 	GlobalFiletypes().registerPattern(filetype::TYPE_MAP, FileTypePattern(_("Map"), "map", "*.map"));
+	GlobalFiletypes().registerPattern(filetype::TYPE_MAP, FileTypePattern(_("Portable Map"), "mapx", "*.mapx"));
 	GlobalFiletypes().registerPattern(filetype::TYPE_REGION, FileTypePattern(_("Region"), "reg", "*.reg"));
+	GlobalFiletypes().registerPattern(filetype::TYPE_PREFAB, FileTypePattern(_("Portable Prefab"), "pfbx", "*.pfbx"));
 	GlobalFiletypes().registerPattern(filetype::TYPE_PREFAB, FileTypePattern(_("Prefab"), "pfb", "*.pfb"));
+
+	GlobalFiletypes().registerPattern(filetype::TYPE_MAP_EXPORT, FileTypePattern(_("Map"), "map", "*.map"));
+	GlobalFiletypes().registerPattern(filetype::TYPE_MAP_EXPORT, FileTypePattern(_("Map"), "mapx", "*.mapx"));
 }
 
 // Utility method to select a map file
@@ -55,7 +60,7 @@ MapFileSelection MapFileManager::selectFile(bool open,
 
 	if (!patterns.empty())
 	{
-		defaultExt = "." + patterns.begin()->extension; // ".map"
+		defaultExt = patterns.begin()->extension; // "map"
 	}
 
 	// Display a file chooser dialog to get a new path
