@@ -27,8 +27,8 @@ private:
 
 	static std::string _infoFileExt;
 
-	// Type of resource "map"
-	std::string _type;
+	// File extension of this resource
+	std::string _extension;
 
 public:
 	// Constructor
@@ -43,7 +43,7 @@ public:
     void setNode(const scene::IMapRootNodePtr& node) override;
 
 	// Save the map contents to the given filename using the given MapFormat export module
-	static bool saveFile(const MapFormat& format, const scene::INodePtr& root,
+	static bool saveFile(const MapFormat& format, const scene::IMapRootNodePtr& root,
 						 const GraphTraversalFunc& traverse, const std::string& filename);
 
 private:
@@ -58,10 +58,6 @@ private:
 
 	void connectMap();
 
-	// Returns the map format capable of loading the given stream
-	// The stream pointer is guaranteed to be positioned back to the beginning
-	MapFormatPtr determineMapFormat(std::istream& stream);
-
 	bool loadFile(std::istream& mapStream, const MapFormat& format, 
                   const RootNodePtr& root, const std::string& filename);
 
