@@ -53,10 +53,6 @@ void thicken(const PatchNodePtr& sourcePatch, float thickness, bool createSeams,
 		// Now create the four walls
 		for (int i = 0; i < 4; i++)
 		{
-			// Insert each node into the same parent as the existing patch
-			// It's vital to do this first, otherwise these patches won't have valid shaders
-			parent->addChildNode(nodes[i]);
-
 			// Retrieve the contained patch from the node
 			Patch* wallPatch = Node_getPatch(nodes[i]);
 
@@ -65,15 +61,19 @@ void thicken(const PatchNodePtr& sourcePatch, float thickness, bool createSeams,
 
 			if (!wallPatch->isDegenerate())
 			{
+				// Insert each node into the same parent as the existing patch
+				// It's vital to do this first, otherwise these patches won't have valid shaders
+				parent->addChildNode(nodes[i]);
+
+				// Now the shader is realised, apply natural scale
+				wallPatch->NaturalTexture();
+
 				// Now select the newly created patch
 				Node_setSelected(nodes[i], true);
 			}
 			else
 			{
 				rMessage() << "Thicken: Discarding degenerate patch." << std::endl;
-
-				// Remove again
-				parent->removeChildNode(nodes[i]);
 			}
 		}
 	}
