@@ -218,12 +218,28 @@ inline void hideNode(const scene::INodePtr& node, bool hide)
 	}
 }
 
+// If the given node has any components of any kind, set the component selection status to the given flag
+inline void setComponentSelection(const scene::INodePtr& node, bool selected)
+{
+	ComponentSelectionTestablePtr componentSelectionTestable = Node_getComponentSelectionTestable(node);
+
+	if (componentSelectionTestable)
+	{
+		componentSelectionTestable->setSelectedComponents(selected, SelectionSystem::eVertex);
+		componentSelectionTestable->setSelectedComponents(selected, SelectionSystem::eEdge);
+		componentSelectionTestable->setSelectedComponents(selected, SelectionSystem::eFace);
+	}
+}
+
 void hideSelected(const cmd::ArgumentList& args)
 {
 	// Traverse the selection, hiding all nodes
 	GlobalSelectionSystem().foreachSelected([] (const scene::INodePtr& node) 
 	{
 		hideSubgraph(node, true);
+
+		// De-select all components of the node that is going to be hidden (#5054)
+		setComponentSelection(node, false);
 	});
 
 	// Then de-select the hidden nodes
@@ -1003,7 +1019,8 @@ void registerCommands()
 	GlobalCommandSystem().addCommand("SelectInside", selectInside);
 	GlobalCommandSystem().addCommand("SelectTouching", selectTouching);
 	GlobalCommandSystem().addCommand("SelectCompleteTall", selectCompleteTall);
-	GlobalCommandSystem().addCommand("ExpandSelectionToEntities", expandSelectionToEntities);
+	GlobalCommandSystem().addCommand("ExpandSelectionToSiblings", expandSelectionToSiblings);
+	GlobalCommandSystem().addCommand("SelectParentEntities", selectParentEntitiesOfSelected);
 	GlobalCommandSystem().addCommand("MergeSelectedEntities", mergeSelectedEntities);
 	GlobalCommandSystem().addCommand("SelectChildren", selectChildren);
 
@@ -1027,14 +1044,14 @@ void registerCommands()
 	GlobalCommandSystem().addCommand("GroupCycleForward", selection::GroupCycle::cycleForward);
 	GlobalCommandSystem().addCommand("GroupCycleBackward", selection::GroupCycle::cycleBackward);
 
-	GlobalCommandSystem().addCommand("TexRotate", rotateTexture, cmd::ARGTYPE_INT|cmd::ARGTYPE_STRING);
-	GlobalCommandSystem().addCommand("TexScale", scaleTexture, cmd::ARGTYPE_VECTOR2|cmd::ARGTYPE_STRING);
-	GlobalCommandSystem().addCommand("TexShift", shiftTextureCmd, cmd::ARGTYPE_VECTOR2|cmd::ARGTYPE_STRING);
+	GlobalCommandSystem().addCommand("TexRotate", rotateTexture, { cmd::ARGTYPE_INT | cmd::ARGTYPE_STRING });
+	GlobalCommandSystem().addCommand("TexScale", scaleTexture, { cmd::ARGTYPE_VECTOR2 | cmd::ARGTYPE_STRING });
+	GlobalCommandSystem().addCommand("TexShift", shiftTextureCmd, { cmd::ARGTYPE_VECTOR2 | cmd::ARGTYPE_STRING });
 
-	GlobalCommandSystem().addCommand("TexAlign", alignTextureCmd, cmd::ARGTYPE_STRING);
+	GlobalCommandSystem().addCommand("TexAlign", alignTextureCmd, { cmd::ARGTYPE_STRING });
 
 	// Add the nudge commands (one general, four specialised ones)
-	GlobalCommandSystem().addCommand("NudgeSelected", nudgeSelectedCmd, cmd::ARGTYPE_STRING);
+	GlobalCommandSystem().addCommand("NudgeSelected", nudgeSelectedCmd, { cmd::ARGTYPE_STRING });
 
 	GlobalCommandSystem().addCommand("NormaliseTexture", normaliseTexture);
 
@@ -1045,7 +1062,7 @@ void registerCommands()
 	GlobalCommandSystem().addCommand("FlipTextureX", flipTextureS);
 	GlobalCommandSystem().addCommand("FlipTextureY", flipTextureT);
 
-	GlobalCommandSystem().addCommand("MoveSelectionVertically", moveSelectedCmd, cmd::ARGTYPE_STRING);
+	GlobalCommandSystem().addCommand("MoveSelectionVertically", moveSelectedCmd, { cmd::ARGTYPE_STRING });
 	
 	GlobalCommandSystem().addCommand("CurveAppendControlPoint", appendCurveControlPoint);
 	GlobalCommandSystem().addCommand("CurveRemoveControlPoint", removeCurveControlPoints);
@@ -1066,7 +1083,7 @@ void registerCommands()
     GlobalCommandSystem().addCommand("CreateCurveCatmullRom", createCurveCatmullRom);
 
 	GlobalCommandSystem().addCommand("FloorSelection", floorSelection);
-	GlobalCommandSystem().addCommand("BrushSetDetailFlag", brushSetDetailFlag, cmd::ARGTYPE_STRING);
+	GlobalCommandSystem().addCommand("BrushSetDetailFlag", brushSetDetailFlag, { cmd::ARGTYPE_STRING });
 	GlobalCommandSystem().addStatement("BrushMakeDetail", "BrushSetDetailFlag detail", false);
 	GlobalCommandSystem().addStatement("BrushMakeStructural", "BrushSetDetailFlag structural", false);
 
@@ -1079,7 +1096,8 @@ void registerCommands()
 	GlobalEventManager().addCommand("SelectInside", "SelectInside");
 	GlobalEventManager().addCommand("SelectTouching", "SelectTouching");
 	GlobalEventManager().addCommand("SelectCompleteTall", "SelectCompleteTall");
-	GlobalEventManager().addCommand("ExpandSelectionToEntities", "ExpandSelectionToEntities");
+	GlobalEventManager().addCommand("ExpandSelectionToSiblings", "ExpandSelectionToSiblings");
+	GlobalEventManager().addCommand("SelectParentEntities", "SelectParentEntities");
 	GlobalEventManager().addCommand("MergeSelectedEntities", "MergeSelectedEntities");
 	GlobalEventManager().addCommand("SelectChildren", "SelectChildren");
 
