@@ -17,6 +17,13 @@ namespace selection {
 
 namespace algorithm {
 
+ISelectionGroupManager& getMapSelectionGroupManager()
+{
+	assert(GlobalMapModule().getRoot());
+
+	return GlobalMapModule().getRoot()->getSelectionGroupManager();
+}
+
 void convertSelectedToFuncStatic(const cmd::ArgumentList& args)
 {
 	UndoableCommand command("convertSelectedToFuncStatic");
@@ -93,7 +100,7 @@ void ParentPrimitivesToEntityWalker::reparent()
 		<< " primitives." << std::endl;
 
 	// Update parent node/subgraph visibility after reparenting
-	scene::UpdateNodeVisibilityWalker updater;
+	scene::UpdateNodeVisibilityWalker updater(_parent->getRootNode());
 
 	// Update the new parent too
 	_parent->traverse(updater);
@@ -326,22 +333,25 @@ void selectChildren(const cmd::ArgumentList& args) {
 
 /**
  * greebo: This walker traverses the entire subgraph,
- *         searching for entities with selected child primitives.
- *         If such an entity is found, it is traversed and all
- *         child primitives are selected.
+ * searching for entities with selected child primitives.
+ * If such an entity is found, it is traversed and all
+ * child primitives are selected.
  */
-class ExpandSelectionToEntitiesWalker :
+class ExpandSelectionToSiblingsWalker :
 	public scene::NodeVisitor
 {
 public:
-	bool pre(const scene::INodePtr& node) {
+	bool pre(const scene::INodePtr& node) override
+	{
 		Entity* entity = Node_getEntity(node);
 
-		if (entity != NULL) {
+		if (entity != nullptr)
+		{
 			// We have an entity, traverse and select children if any child is selected
 			return entity->isContainer() && (Node_isSelected(node) || Node_hasSelectedChildNodes(node));
 		}
-		else if (Node_isPrimitive(node)) {
+		else if (Node_isPrimitive(node))
+		{
 			// We have a primitive, select it
 			Node_setSelected(node, true);
 			// Don't traverse any deeper
@@ -352,8 +362,51 @@ public:
 	}
 };
 
-void expandSelectionToEntities(const cmd::ArgumentList& args) {
-	ExpandSelectionToEntitiesWalker walker;
+void expandSelectionToSiblings(const cmd::ArgumentList& args)
+{
+	ExpandSelectionToSiblingsWalker walker;
+	GlobalSceneGraph().root()->traverse(walker);
+}
+
+/**
+ * greebo: This walker traverses the entire subgraph,
+ * searching for entities with selected child primitives.
+ * If such an entity is found, it will be selected in place
+ * of the child primitive.
+ */
+class PropagateSelectionToParentEntityWalker :
+	public scene::NodeVisitor
+{
+public:
+	bool pre(const scene::INodePtr& node) override
+	{
+		Entity* entity = Node_getEntity(node);
+
+		if (entity != nullptr)
+		{
+			if (entity->isContainer() && !entity->isWorldspawn() && Node_hasSelectedChildNodes(node))
+			{
+				// De-select all child primitives
+				node->foreachNode([](const scene::INodePtr& child)->bool
+				{
+					Node_setSelected(child, false);
+					return true;
+				});
+
+				// Select the entity instead
+				Node_setSelected(node, true);
+			}
+
+			return false; // don't traverse entities, that's covered by Node_hasSelectedChildNodes
+		}
+
+		return true;
+	}
+};
+
+void selectParentEntitiesOfSelected(const cmd::ArgumentList& args)
+{
+	PropagateSelectionToParentEntityWalker walker;
 	GlobalSceneGraph().root()->traverse(walker);
 }
 
@@ -397,6 +450,11 @@ void mergeSelectedEntities(const cmd::ArgumentList& args)
 
 void checkGroupSelectedAvailable()
 {
+	if (!GlobalMap().getRoot())
+	{
+		throw CommandNotAvailableException(_("No map loaded"));
+	}
+
 	if (GlobalSelectionSystem().Mode() != SelectionSystem::ePrimitive &&
 		GlobalSelectionSystem().Mode() != SelectionSystem::eGroupPart)
 	{
@@ -447,7 +505,7 @@ void groupSelected()
 
 	UndoableCommand cmd("GroupSelected");
 
-	ISelectionGroupPtr group = GlobalSelectionGroupManager().createSelectionGroup();
+	ISelectionGroupPtr group = getMapSelectionGroupManager().createSelectionGroup();
 
 	GlobalSelectionSystem().foreachSelected([&](const scene::INodePtr& node)
 	{
@@ -459,6 +517,11 @@ void groupSelected()
 
 void checkUngroupSelectedAvailable()
 {
+	if (!GlobalMap().getRoot())
+	{
+		throw CommandNotAvailableException(_("No map loaded"));
+	}
+
 	if (GlobalSelectionSystem().Mode() != SelectionSystem::ePrimitive &&
 		GlobalSelectionSystem().Mode() != SelectionSystem::eGroupPart)
 	{
@@ -513,15 +576,55 @@ void ungroupSelected()
 		}
 	});
 
+	auto& selGroupMgr = getMapSelectionGroupManager();
+
 	// Now remove the found group by ID (maybe convert them to a selection set before removal?)
-	std::for_each(ids.begin(), ids.end(), [](std::size_t id)
+	std::for_each(ids.begin(), ids.end(), [&](std::size_t id)
 	{
-		GlobalSelectionGroupManager().deleteSelectionGroup(id);
+		selGroupMgr.deleteSelectionGroup(id);
 	});
 
 	GlobalMainFrame().updateAllWindows();
 }
 
+void deleteAllSelectionGroupsCmd(const cmd::ArgumentList& args)
+{
+	if (!GlobalMap().getRoot())
+	{
+		rError() << "No map loaded, cannot delete groups." << std::endl;
+		return;
+	}
+
+	UndoableCommand cmd("DeleteAllSelectionGroups");
+	getMapSelectionGroupManager().deleteAllSelectionGroups();
+}
+
+void groupSelectedCmd(const cmd::ArgumentList& args)
+{
+	try
+	{
+		groupSelected();
+	}
+	catch (CommandNotAvailableException & ex)
+	{
+		rError() << ex.what() << std::endl;
+		wxutil::Messagebox::ShowError(ex.what());
+	}
+}
+
+void ungroupSelectedCmd(const cmd::ArgumentList& args)
+{
+	try
+	{
+		ungroupSelected();
+	}
+	catch (CommandNotAvailableException & ex)
+	{
+		rError() << ex.what() << std::endl;
+		wxutil::Messagebox::ShowError(ex.what());
+	}
+}
+
 } // namespace algorithm
 
 } // namespace selection
