@@ -6,8 +6,13 @@
 #include <list>
 #include "CommandNotAvailableException.h"
 
-namespace selection {
-	namespace algorithm {
+namespace selection 
+{
+
+class ISelectionGroupManager;
+
+namespace algorithm 
+{
 
 	class ParentPrimitivesToEntityWalker :
 		public SelectionSystem::Visitor,
@@ -120,14 +125,21 @@ namespace selection {
 
 	/**
 	 * greebo: This selects all the children of an entity, given the case
-	 *         that a child of this entity is already selected. For instance,
-	 *         if a child brush of a func_static is selected, this command
-	 *         expands the selection to all other children (but not the
-	 *         func_static entity itself). Select a single primitive of
-	 *         the worldspawn entity and this command will select every primitive
-	 *         that is child of worldspawn.
+	 * that a child of this entity is already selected. For instance,
+	 * if a child brush of a func_static is selected, this command
+	 * expands the selection to all other children (but not the
+	 * func_static entity itself). Select a single primitive of
+	 * the worldspawn entity and this command will select every primitive
+	 * that is child of worldspawn.
 	 */
-	void expandSelectionToEntities(const cmd::ArgumentList& args);
+	void expandSelectionToSiblings(const cmd::ArgumentList& args);
+
+	/**
+	 * greebo: This will select the parent entity of any currently selected 
+	 * primitve. The child primitive will be deselected and the parent entity
+	 * will be selected instead.
+	 */
+	void selectParentEntitiesOfSelected(const cmd::ArgumentList& args);
 
 	/**
 	 * greebo: Merges all selected group nodes (func_* entities).
@@ -137,6 +149,12 @@ namespace selection {
 	 */
 	void mergeSelectedEntities(const cmd::ArgumentList& args);
 
+	/**
+	 * Returns the selection group manager of the current map's root node.
+	 * This will fail if there is no map root node, check this first.
+	 */
+	ISelectionGroupManager& getMapSelectionGroupManager();
+
 	/**
 	 * Groups the currently selected elements.
 	 * Will throw a CommandNotAvailableException if it cannot execute.
@@ -161,5 +179,10 @@ namespace selection {
 	*/
 	void checkUngroupSelectedAvailable();
 
-	} // namespace algorithm
+	// Command targets
+	void deleteAllSelectionGroupsCmd(const cmd::ArgumentList& args);
+	void groupSelectedCmd(const cmd::ArgumentList& args);
+	void ungroupSelectedCmd(const cmd::ArgumentList& args);
+
+} // namespace algorithm
 } // namespace selection
