@@ -7,6 +7,8 @@
 #include "map/Map.h"
 #include "camera/GlobalCamera.h"
 #include "brush/FaceInstance.h"
+#include "map/format/portable/PortableMapFormat.h"
+#include "map/algorithm/Import.h"
 #include "selection/algorithm/General.h"
 #include "selection/algorithm/Transformation.h"
 
@@ -18,18 +20,20 @@ namespace clipboard
 
 void pasteToMap()
 {
-    GlobalSelectionSystem().setSelectedAll(false);
-    std::stringstream str(wxutil::pasteFromClipboard());
-    GlobalMap().importSelected(str);
+    std::stringstream stream(wxutil::pasteFromClipboard());
+	map::algorithm::importFromStream(stream);
 }
 
 void copy(const cmd::ArgumentList& args)
 {
 	if (FaceInstance::Selection().empty())
     {
+		// When exporting to the system clipboard, use the portable format
+		auto format = GlobalMapFormatManager().getMapFormatByName(map::format::PortableMapFormat::Name);
+
         // Stream selected objects into a stringstream
         std::stringstream out;
-        GlobalMap().exportSelected(out);
+        GlobalMap().exportSelected(out, format);
 
         // Copy the resulting string to the clipboard
         wxutil::copyToClipboard(out.str());
