@@ -54,7 +54,6 @@ public:
 			name(add(wxutil::TreeModel::Column::IconText)),
 			value(add(wxutil::TreeModel::Column::String)),
 			isInherited(add(wxutil::TreeModel::Column::Boolean)),
-			helpIcon(add(wxutil::TreeModel::Column::Icon)),
 			hasHelpText(add(wxutil::TreeModel::Column::Boolean)),
 			booleanValue(add(wxutil::TreeModel::Column::Boolean))
 		{}
@@ -62,14 +61,12 @@ public:
 		wxutil::TreeModel::Column name;
 		wxutil::TreeModel::Column value;
 		wxutil::TreeModel::Column isInherited;
-		wxutil::TreeModel::Column helpIcon;
 		wxutil::TreeModel::Column hasHelpText;
 		wxutil::TreeModel::Column booleanValue;
 	};
 
 private:
-	struct StringCompareFunctorNoCase :
-		public std::binary_function<std::string, std::string, bool>
+	struct StringCompareFunctorNoCase
 	{
 		bool operator()(const std::string& s1, const std::string& s2) const
 		{
@@ -102,8 +99,6 @@ private:
 
 	wxIcon _emptyIcon;
 
-	wxDataViewColumn* _helpColumn;
-
     // Cache of wxDataViewItems pointing to keyvalue rows,
 	// so we can quickly find existing keys to change their values
 	typedef std::map<std::string, wxDataViewItem, StringCompareFunctorNoCase> TreeIterMap;
@@ -180,12 +175,12 @@ private:
     // callbacks
 	void _onEntryActivate(wxCommandEvent& ev);
 	void _onSetProperty(wxCommandEvent& ev);
-	void _onToggleShowInherited(wxCommandEvent& ev);
-	void _onToggleShowHelpIcons(wxCommandEvent& ev);
 	void _onTreeViewSelectionChanged(wxDataViewEvent& ev);
 	void _onContextMenu(wxDataViewEvent& ev);
 	void _onDataViewItemChanged(wxDataViewEvent& ev);
 
+	void handleShowInheritedChanged();
+	void handleShowHelpTextChanged();
 	void updateHelpText(const wxutil::TreeModel::Row& row);
     static std::string  cleanInputString( const std::string& );
 
