@@ -1,9 +1,11 @@
 #pragma once
 
+#include <memory>
 #include "wxutil/PanedPosition.h"
 #include "imainframelayout.h"
 
 #include "camera/CamWnd.h"
+#include "ui/widgets/Splitter.h"
 
 namespace ui
 {
@@ -20,11 +22,15 @@ private:
 	// The camera view
 	CamWndPtr _camWnd;
 
-	wxSplitterWindow* _horizPane;
-	wxSplitterWindow* _groupCamPane;
+	Splitter* _horizPane;
+	Splitter* _groupCamPane;
 
-	wxutil::PanedPosition _posHPane;
-	wxutil::PanedPosition _posGroupCamPane;
+	struct SavedPositions
+	{
+		int horizSashPosition;
+		int groupCamSashPosition;
+	};
+	std::unique_ptr<SavedPositions> _savedPositions;
 
 public:
 	// IMainFrameLayout implementation
@@ -36,14 +42,6 @@ public:
 
 	// The creation function, needed by the mainframe layout manager
 	static EmbeddedLayoutPtr CreateInstance();
-
-private:
-	void maximiseCameraSize();
-	void restorePanePositions();
-
-	// Saves the state of this window layout to the given XMLRegistry path (without trailing slash)
-	void restoreStateFromPath(const std::string& path);
-	void saveStateToPath(const std::string& path);
 };
 
 } // namespace ui
