@@ -48,7 +48,8 @@ protected:
 	// Thread entry point
 	ExitCode Entry();
 
-    void visitFile(const std::string& filename);
+    void visitFile(const vfs::FileInfo& fileInfo);
+	void searchForFilesMatchingExtension(const std::string& extension);
 };
 
 }
