@@ -34,6 +34,7 @@
 #include "XYRenderer.h"
 #include "gamelib.h"
 #include "scenelib.h"
+#include "maplib.h"
 #include "render/frontend/RenderableCollectionWalker.h"
 
 #include <fmt/format.h>
@@ -117,6 +118,12 @@ XYWnd::XYWnd(int id, wxWindow* parent) :
 	_wxGLWidget->Connect(wxEVT_MIDDLE_DOWN, wxMouseEventHandler(XYWnd::onGLMouseButtonPress), NULL, this);
     _wxGLWidget->Connect(wxEVT_MIDDLE_DCLICK, wxMouseEventHandler(XYWnd::onGLMouseButtonPress), NULL, this);
 	_wxGLWidget->Connect(wxEVT_MIDDLE_UP, wxMouseEventHandler(XYWnd::onGLMouseButtonRelease), NULL, this);
+	_wxGLWidget->Connect(wxEVT_AUX1_DOWN, wxMouseEventHandler(XYWnd::onGLMouseButtonPress), NULL, this);
+	_wxGLWidget->Connect(wxEVT_AUX1_DCLICK, wxMouseEventHandler(XYWnd::onGLMouseButtonPress), NULL, this);
+	_wxGLWidget->Connect(wxEVT_AUX1_UP, wxMouseEventHandler(XYWnd::onGLMouseButtonRelease), NULL, this);
+	_wxGLWidget->Connect(wxEVT_AUX2_DOWN, wxMouseEventHandler(XYWnd::onGLMouseButtonPress), NULL, this);
+	_wxGLWidget->Connect(wxEVT_AUX2_DCLICK, wxMouseEventHandler(XYWnd::onGLMouseButtonPress), NULL, this);
+	_wxGLWidget->Connect(wxEVT_AUX2_UP, wxMouseEventHandler(XYWnd::onGLMouseButtonRelease), NULL, this);
 
 	_wxGLWidget->Connect(wxEVT_IDLE, wxIdleEventHandler(XYWnd::onIdle), NULL, this);
 
@@ -933,14 +940,15 @@ void XYWnd::drawGrid()
 
 void XYWnd::drawBlockGrid()
 {
-    if (GlobalMap().getWorldspawn() == NULL) {
-        return; // no worldspawn yet
-    }
+    // Do nothing if there is no worldspawn yet
+    Entity* worldSpawn = map::current::getWorldspawn();
+    if (!worldSpawn)
+        return;
+
     // Set a default blocksize of 1024
     int blockSize = GlobalXYWnd().defaultBlockSize();
 
     // Check the worldspawn for a custom blocksize
-    Entity* worldSpawn = Node_getEntity(GlobalMap().getWorldspawn());
     assert(worldSpawn);
     std::string sizeVal = worldSpawn->getKeyValue("_blocksize");
 
@@ -1326,31 +1334,31 @@ void XYWnd::draw()
 
     glDepthMask(GL_FALSE);
 
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
 
     glLoadMatrixd(_modelView);
 
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
     glDisable(GL_LINE_STIPPLE);
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
     glLineWidth(1);
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
     if (GLEW_VERSION_1_3) {
         glActiveTexture(GL_TEXTURE0);
         glClientActiveTexture(GL_TEXTURE0);
     }
     glDisableClientState(GL_TEXTURE_COORD_ARRAY);
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
     glDisableClientState(GL_NORMAL_ARRAY);
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
     glDisableClientState(GL_COLOR_ARRAY);
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
     glDisable(GL_TEXTURE_2D);
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
     glDisable(GL_LIGHTING);
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
     glDisable(GL_COLOR_MATERIAL);
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
 
     // greebo: Check, if the size info should be displayed (if there are any items selected)
     if (xyWndManager.showSizeInfo() && GlobalSelectionSystem().countSelected() != 0)
@@ -1400,7 +1408,7 @@ void XYWnd::draw()
         glPointSize(1);
     }
 
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
 
     // reset modelview
     glLoadIdentity();
@@ -1458,11 +1466,11 @@ void XYWnd::draw()
         }
     }
 
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
 
     // Reset the depth mask to its initial value (enabled)
     glDepthMask(GL_TRUE);
-    GlobalOpenGL().assertNoErrors();
+    debug::assertNoGlErrors();
 
     glFinish();
 }
